==> linuxconf-1.32r1.bin-elf.tar.gz: usr/lib/linuxconf/help.cs/firewall-msg-1.32r1.cs <==
g  firewall              p          F  d        /  <  S  e                      
        5  f                  #  4  =  O  Z  d  l            
  !  ?  _                &  7                  	  	  	!  	1  	o  	  	  	  	  	  	  	  	  
  
8  
F  
[  
s  
  
  
  
    @  b                  ]  j  o  s          
  
Pravidla pro firewall Povoleno	Proto	Rozhr	Z	<->	Rozhr	Do Pomoc [Pidej] lze definovat nov pravidlo Upravit pravidla pro firewall Zde lze upravit/pidat/mazat pravidla Nastala chyba, firewall nebyl aktivovn

%s Linuxconf byl zkompilovnse starm jdrem a nepodporuje
firewall korektn. Pravidla nebudou aktivovna. Vstupn pravidla jsou aktivn Pravidla pro pedvn Vstupn pravidla Pravidla pro kontrolu paket Speciln moduly jdra CuSeeMe FTP IRC Real Audio Quake Vdolive vyadovn Porty pro IRC (nepov) Celkov ovldn firewallu/kontroly paket Zde ze povolit/zakzat vechny skupiny pravidel
bez jejich smazn. Uvdomte si, e povolen
przdn mnoiny zakazuje ve!!! Neplatn syntax pro IRC porty
oekvn port [ , port ...]
kde port je slo mezi 1024 a 65000 Neplatn IP adresa, jmno potae nebo rozhran: %s
 Chyb pota nebo s Rozsah port povolen jen pro protokoly TCP a UDP Neplatn rozsah port
Oekvn xxxx:yyyy Seznam port povolen jen pro protokoly TCP a UDP Neplatn seznam port Protokol Odeslatel Pota nebo s Sov maska Rozsah port Ostatn porty Paket odkudkoliv Pjemce Neplatn protocol Akceptovat Odmtnout Zakzat Politika pro pravidla Toto pravidlo je aktivn Zapnout makardu Pravidlo pro pedvn pes firewall Pravidlo pro vystupn firewall Pesmrovat na lokln port Psmrovat na port Pravidlo pro vstupn firewall Pravidlo pro kontrolu paket IP Neplatn rozhran %s pro pravidlo modul firewall

    dn pepnae pkazov dky
 Neplatn sov maska Obecn nastaven Blokovac firewall Pedvc firewall Vstupn firewall Kontrola paket Vypnout firewall Pravidla pro firewall byly vypnuty.
Budou opt aktivovna, kdy nechte
pt Linuxconf aktivovat zmny.
 Nastavuji firewall Firewall Accept TCP Syn packet This rule is bidirectional Ordering factor Comment Features Output interface Input interface Excluded: Some information are missing to process those rules Logical host %s does not exist Logging is enabled Auto Forwarding Firewall Mark Forwarding Port Forwarding Space Control IpSec VPN support PPTP VPN support Firewall state does not match configuration
 Rules control Extra kernel modules Kernel module + options Redir. to host Redirections Invalid dispatch token %*.*s in section %s, rule %d
Chain dispatch will be ignored Firewall configuration Can't dispatch for protocol ALL Can't dispatch by port for protocol %s Invalid network specification: %s Internal error in section %s, rule %d Input firewalling Forward firewalling Output firewalling Packet accounting Linuxconf internal Chain dispatch (from -> to) Chain dispatch (to -> from) The kernel does not support ipchain firewalling
reconfigure it Client ports None All No interface specified, can't dispatch Features Update the kernel rules gracefully The kernel does not support iptables firewalling
reconfigure it Use IP Chains even on kernel 2.4 

==> linuxconf-1.34r3.bin-elf.tar.gz: usr/lib/linuxconf/help.cs/firewall-msg-1.34r3.cs <==
g  firewall              p          F  d        /  <  S  e                      
        5  f                  #  4  =  O  Z  d  l            
  !  ?  _                &  7                  	  	  	!  	1  	o  	  	  	  	  	  	  	  	  
  
8  
F  
[  
s  
  
  
  
    @  b  =  O  c  v          
  
  
$  
(  
O  
X  
p  
{  
  
Pravidla pro firewall Povoleno	Proto	Rozhr	Z	<->	Rozhr	Do Pomoc [Pidej] lze definovat nov pravidlo Upravit pravidla pro firewall Zde lze upravit/pidat/mazat pravidla Nastala chyba, firewall nebyl aktivovn

%s Linuxconf byl zkompilovnse starm jdrem a nepodporuje
firewall korektn. Pravidla nebudou aktivovna. Vstupn pravidla jsou aktivn Pravidla pro pedvn Vstupn pravidla Pravidla pro kontrolu paket Speciln moduly jdra CuSeeMe FTP IRC Real Audio Quake Vdolive vyadovn Porty pro IRC (nepov) Celkov ovldn firewallu/kontroly paket Zde ze povolit/zakzat vechny skupiny pravidel
bez jejich smazn. Uvdomte si, e povolen
przdn mnoiny zakazuje ve!!! Neplatn syntax pro IRC porty
oekvn port [ , port ...]
kde port je slo mezi 1024 a 65000 Neplatn IP adresa, jmno potae nebo rozhran: %s
 Chyb pota nebo s Rozsah port povolen jen pro protokoly TCP a UDP Neplatn rozsah port
Oekvn xxxx:yyyy Seznam port povolen jen pro protokoly TCP a UDP Neplatn seznam port Protokol Odeslatel Pota nebo s Sov maska Rozsah port Ostatn porty Paket odkudkoliv Pjemce Neplatn protocol Akceptovat Odmtnout Zakzat Politika pro pravidla Toto pravidlo je aktivn Zapnout makardu Pravidlo pro pedvn pes firewall Pravidlo pro vystupn firewall Pesmrovat na lokln port Psmrovat na port Pravidlo pro vstupn firewall Pravidlo pro kontrolu paket IP Neplatn rozhran %s pro pravidlo modul firewall

    dn pepnae pkazov dky
 Neplatn sov maska Obecn nastaven Blokovac firewall Pedvc firewall Vstupn firewall Kontrola paket Vypnout firewall Pravidla pro firewall byly vypnuty.
Budou opt aktivovna, kdy nechte
pt Linuxconf aktivovat zmny.
 Nastavuji firewall Firewall Accept TCP Syn packet This rule is bidirectional Ordering factor Comment Features Output interface Input interface Excluded: Some information are missing to process those rules Logical host %s does not exist Logging is enabled Auto Forwarding Firewall Mark Forwarding Port Forwarding Space Control IpSec VPN support PPTP VPN support Firewall state does not match configuration
 Rules control Extra kernel modules Kernel module + options Redir. to host Redirections Invalid dispatch token %*.*s in section %s, rule %d
Chain dispatch will be ignored Firewall configuration Can't dispatch for protocol ALL Can't dispatch by port for protocol %s Invalid network specification: %s Internal error in section %s, rule %d
From interface %s protocol %s ip %s mask %s
From portrange %s ports %s
To   interface %s protocol %s ip %s mask %s
To   portrange %s ports %s
redirport %s loggin %d syn_packets %d
 Input firewalling Forward firewalling Output firewalling Packet accounting Linuxconf internal Chain dispatch (from -> to) Chain dispatch (to -> from) The kernel does not support ipchain firewalling
reconfigure it Client ports None All No interface specified, can't dispatch Features Update the kernel rules gracefully The kernel does not support iptables firewalling
reconfigure it Use IP Chains even on kernel 2.4 
